#!/bin/bash

# Copyright (c) 2012 Cloudera, Inc. All rights reserved.

# Time marker for both stderr and stdout
date; date 1>&2

cloudera_config=`dirname $0`
cloudera_config=`cd "$cloudera_config/../common"; pwd`
. ${cloudera_config}/cloudera-config.sh

# attempt to find java
locate_java_home

# Load the parcel environment
source_parcel_environment

. ${cloudera_config}/cdh4-default

echo "using $JAVA_HOME as JAVA_HOME"
echo "using $CDH_VERSION as CDH_VERSION"
echo "using $CDH_YARN_HOME as CDH_YARN_HOME"
echo "using $CDH_MR2_HOME as CDH_MR2_HOME"
echo "using $CONF_DIR as CONF_DIR"

export YARN_CONF_DIR=$CONF_DIR

YARN=$CDH_YARN_HOME/bin/yarn

# debug
set -x

# local replacement of substitution variables.
# i.e. master doesn't know final resting place of configuration files
#   which may require absolute path (e.g. dfs_allows)
perl -pi -e "s#{{CMF_CONF_DIR}}#$CONF_DIR#g" $CONF_DIR/*.xml

if [ -e $CONF_DIR/topology.py ]; then
  perl -pi -e "s#{{CMF_CONF_DIR}}#$CONF_DIR#g" $CONF_DIR/topology.py
  # Make sure topology.py is executable
  chmod +x $CONF_DIR/topology.py
fi

# Disable IPv6.
export YARN_OPTS="-Djava.net.preferIPv4Stack=true $YARN_OPTS"

acquire_kerberos_tgt yarn.keytab

if [ $1 = "RefreshQueuesAndNodes" ]; then
  $YARN --config $CONF_DIR rmadmin -refreshQueues
  #RET=$?
  # Ignore error code for now due to MAPREDUCE-3763
  RET=0
  if [ $RET -eq 0 ]; then
    echo "RefreshQueues completed successfully"
    $YARN --config $CONF_DIR rmadmin -refreshNodes
    RET=$?
    if [ $RET -eq 0 ]; then
      echo "RefreshNodes completed successfully"
    else
      echo "RefreshNodes failed"
    fi
  else
    echo "RefreshQueues failed. Skipping RefreshNodes."
  fi
  exit $RET
elif [ $1 = "historyserver" ]; then
  # historyserver is actually a MR2 daemon.
  MAPRED=$HADOOP_MAPRED_HOME/bin/mapred
  exec $MAPRED "$@"
else
  if [ $1 = "nodemanager" ]; then
    # In secure mode, container are launched as user who submitted the job and
    # needs read access to the config dir
    chmod go+r $CONF_DIR $CONF_DIR/*
  fi
  
  exec $YARN "$@"
fi
